Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/action/execute/ExecuteAddBug.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/action/execute/ExecuteAddBug.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/action/execute/ExecuteAddBug.java	(revision 27874)
@@ -50,5 +50,5 @@
 import org.openstreetmap.josm.plugins.mapdust.service.value.MapdustBug;
 import org.openstreetmap.josm.plugins.mapdust.service.value.Status;
-import org.openstreetmap.josm.plugins.mapdust.service.value.Type;
+import org.openstreetmap.josm.plugins.mapdust.service.value.BugType;
 
 
@@ -104,5 +104,5 @@
         if (event != null) {
             CreateBugDialog createDialog = (CreateBugDialog) getDialog();
-            Type type = (Type) (createDialog).getCbbType().getSelectedItem();
+            BugType type = (BugType) (createDialog).getCbbType().getSelectedItem();
             String nickname = createDialog.getTxtNickname().getText();
             String commentText = createDialog.getTxtDescription().getText();
Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/ChangeBugStatusDialog.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/ChangeBugStatusDialog.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/ChangeBugStatusDialog.java	(revision 27874)
@@ -280,7 +280,6 @@
      * @return the type
      */
-    public String getType() {
-        return this.type;
-    }
+// caused compile error
+//    public String getType() {        return this.type;    }
 
 }
Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/FilterBugDialog.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/FilterBugDialog.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/dialog/FilterBugDialog.java	(revision 27874)
@@ -55,5 +55,5 @@
 import org.openstreetmap.josm.plugins.mapdust.service.value.MapdustRelevance;
 import org.openstreetmap.josm.plugins.mapdust.service.value.Status;
-import org.openstreetmap.josm.plugins.mapdust.service.value.Type;
+import org.openstreetmap.josm.plugins.mapdust.service.value.BugType;
 import org.openstreetmap.josm.tools.ImageProvider;
 
@@ -66,4 +66,5 @@
  */
 public class FilterBugDialog extends AbstractDialog {
+    org.openstreetmap.josm.plugins.mapdust.service.value.BugType ttt=org.openstreetmap.josm.plugins.mapdust.service.value.BugType.WRONG_TURN;
 
     /** The serial version UID */
@@ -282,39 +283,39 @@
 
         /* wrong_turn type */
-        filterTypes[0] = new FilterCheckBox(Type.WRONG_TURN.getKey(),
+        filterTypes[0] = new FilterCheckBox(BugType.WRONG_TURN.getKey(),
                 new Rectangle(110, 90, 20, 25), "dialogs/wrong_turn.png",
-                Type.WRONG_TURN.getValue(), new Rectangle(130, 90, 120, 25));
+                BugType.WRONG_TURN.getValue(), new Rectangle(130, 90, 120, 25));
         /* bad_routing type */
-        filterTypes[1] = new FilterCheckBox(Type.WRONG_ROUNDABOUT.getKey(),
+        filterTypes[1] = new FilterCheckBox(BugType.WRONG_ROUNDABOUT.getKey(),
                 new Rectangle(270, 90, 20, 25), "dialogs/wrong_roundabout.png",
-                Type.WRONG_ROUNDABOUT.getValue(), new Rectangle(290, 90, 180,
+                BugType.WRONG_ROUNDABOUT.getValue(), new Rectangle(290, 90, 180,
                         25));
         /* oneway_road type */
-        filterTypes[2] =  new FilterCheckBox(Type.MISSING_STREET.getKey(),
+        filterTypes[2] =  new FilterCheckBox(BugType.MISSING_STREET.getKey(),
                 new Rectangle(110, 125, 20, 25), "dialogs/missing_street.png",
-                Type.MISSING_STREET.getValue(), new Rectangle(130, 125, 150,
+                BugType.MISSING_STREET.getValue(), new Rectangle(130, 125, 150,
                         25));
         /* blocked_street type */
-        filterTypes[3] = new FilterCheckBox(Type.BLOCKED_STREET.getKey(),
+        filterTypes[3] = new FilterCheckBox(BugType.BLOCKED_STREET.getKey(),
                 new Rectangle(270, 125, 20, 25), "dialogs/blocked_street.png",
-                Type.BLOCKED_STREET.getValue(), new Rectangle(290, 125, 180,
+                BugType.BLOCKED_STREET.getValue(), new Rectangle(290, 125, 180,
                         25));
         /* missing_street type */
-        filterTypes[4] = new FilterCheckBox(Type.BAD_ROUTING.getKey(),
+        filterTypes[4] = new FilterCheckBox(BugType.BAD_ROUTING.getKey(),
                 new Rectangle(110, 160, 20, 25), "dialogs/bad_routing.png",
-                Type.BAD_ROUTING.getValue(), new Rectangle(130, 160, 150, 25));
+                BugType.BAD_ROUTING.getValue(), new Rectangle(130, 160, 150, 25));
         /* wrong_roundabout type */
-        filterTypes[5] = new FilterCheckBox(Type.MISSING_SPEEDLIMIT.getKey(),
+        filterTypes[5] = new FilterCheckBox(BugType.MISSING_SPEEDLIMIT.getKey(),
                 new Rectangle(270, 160, 20, 25), "dialogs/missing_speedlimit.png",
-                Type.MISSING_SPEEDLIMIT.getValue(), new Rectangle(290, 160,
+                BugType.MISSING_SPEEDLIMIT.getValue(), new Rectangle(290, 160,
                         180, 25));
         /* missing_speedlimit type */
-        filterTypes[6] = new FilterCheckBox(Type.OTHER.getKey(),
+        filterTypes[6] = new FilterCheckBox(BugType.OTHER.getKey(),
                 new Rectangle(110, 195, 20, 25), "dialogs/other.png",
-                Type.OTHER.getValue(), new Rectangle(130, 195, 150, 25));
+                BugType.OTHER.getValue(), new Rectangle(130, 195, 150, 25));
         /* other type */
-        filterTypes[7] = new FilterCheckBox(Type.ONEWAY_ROAD.getKey(),
+        filterTypes[7] = new FilterCheckBox(BugType.ONEWAY_ROAD.getKey(),
                 new Rectangle(270, 195, 20, 25), "dialogs/oneway_road.png",
-                Type.ONEWAY_ROAD.getValue(), new Rectangle(290, 195, 180, 25));
+                BugType.ONEWAY_ROAD.getValue(), new Rectangle(290, 195, 180, 25));
 
         if (prevFilter != null && prevFilter.getTypes() != null) {
Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/renderer/ComboBoxRenderer.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/renderer/ComboBoxRenderer.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/renderer/ComboBoxRenderer.java	(revision 27874)
@@ -36,5 +36,5 @@
 import javax.swing.JList;
 import javax.swing.ListCellRenderer;
-import org.openstreetmap.josm.plugins.mapdust.service.value.Type;
+import org.openstreetmap.josm.plugins.mapdust.service.value.BugType;
 import org.openstreetmap.josm.tools.ImageProvider;
 
@@ -65,6 +65,6 @@
         JLabel label = (JLabel) defaultRenderer.getListCellRendererComponent(
                 list, value, index, isSelected, cellHasFocus);
-        if (value instanceof Type) {
-            Type type = (Type) value;
+        if (value instanceof BugType) {
+            BugType type = (BugType) value;
             String iconPath = "bugs/normal/open_" + type.getKey() + ".png";
             String text = type.getValue();
Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/converter/MapdustConverter.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/converter/MapdustConverter.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/converter/MapdustConverter.java	(revision 27874)
@@ -42,5 +42,5 @@
 import org.openstreetmap.josm.plugins.mapdust.service.value.MapdustRelevance;
 import org.openstreetmap.josm.plugins.mapdust.service.value.Status;
-import org.openstreetmap.josm.plugins.mapdust.service.value.Type;
+import org.openstreetmap.josm.plugins.mapdust.service.value.BugType;
 
 
@@ -85,5 +85,5 @@
                 bug.setStatus(status);
                 /* sets the type */
-                Type type = Type.getType(bugProperties.getType());
+                BugType type = BugType.getType(bugProperties.getType());
                 bug.setType(type);
                 /* sets the relevance */
@@ -177,5 +177,5 @@
                 bug.setStatus(status);
                 /* sets the type */
-                Type type = Type.getType(bugProperties.getType());
+                BugType type = BugType.getType(bugProperties.getType());
                 bug.setType(type);
                 /* sets the relevance */
Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/value/MapdustBug.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/value/MapdustBug.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/value/MapdustBug.java	(revision 27874)
@@ -60,5 +60,5 @@
 
     /** The type of the object */
-    private Type type;
+    private BugType type;
 
     /** The relevance of the object */
@@ -105,5 +105,5 @@
      * @param nickname The nickname of the user who created the bug
      */
-    public MapdustBug(LatLon latLon, Type type, String description,
+    public MapdustBug(LatLon latLon, BugType type, String description,
             String nickname) {
         this.latLon = latLon;
@@ -136,5 +136,5 @@
      */
     public MapdustBug(Long id, LatLon latLon, Address address,
-            Date dateCreated, Date dateUpdated, Status status, Type type,
+            Date dateCreated, Date dateUpdated, Status status, BugType type,
             MapdustRelevance relevance, String description,
             boolean isDefaultDescription, String nickname, String skoUid,
@@ -255,5 +255,5 @@
      * @return the type
      */
-    public Type getType() {
+    public BugType getType() {
         return type;
     }
@@ -264,5 +264,5 @@
      * @param type the type to set
      */
-    public void setType(Type type) {
+    public void setType(BugType type) {
         this.type = type;
     }
Index: plications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/value/Type.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/service/value/Type.java	(revision 27873)
+++ 	(revision )
@@ -1,189 +1,0 @@
-/* Copyright (c) 2010, skobbler GmbH
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- *    this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- *    this list of conditions and the following disclaimer in the documentation
- *    and/or other materials provided with the distribution.
- * 3. Neither the name of the project nor the names of its
- *    contributors may be used to endorse or promote products derived from this
- *    software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- */
-package org.openstreetmap.josm.plugins.mapdust.service.value;
-
-
-import java.io.Serializable;
-import java.util.Collection;
-import java.util.HashMap;
-
-
-/**
- * Defines the values for the <code>Type</code>.
- *
- * @author Bea
- *
- */
-public class Type implements Serializable {
-
-    /** The serial version UID */
-    private static final long serialVersionUID = 4022464908172242274L;
-
-    /** The key of the <code>Type</code> */
-    private String key;
-
-    /** The value of the <code>Type</code> */
-    private String value;
-
-    /** The hash map containing the valid values */
-    private static java.util.HashMap<String, Type> table = null;
-
-    /**
-     * Builds a new <code>Type</code> object
-     */
-    public Type() {}
-
-    /**
-     * Builds a new <code>status</code> object
-     *
-     * @param key The key of the object
-     * @param value The value of the object
-     */
-    public Type(String key, String value) {
-        this.key = key;
-        this.value = value;
-        if (Type.table == null) {
-            Type.table = new HashMap<String, Type>();
-        }
-        Type.table.put(key, this);
-    }
-
-    /** The wrong turn <code>Type</code> */
-    public static final Type WRONG_TURN = new Type("wrong_turn", "Wrong turn");
-
-    /** The bad routing <code>Type</code> */
-    public static final Type BAD_ROUTING = new Type("bad_routing",
-            "Bad routing");
-
-    /** The oneway road <code>Type</code> */
-    public static final Type ONEWAY_ROAD = new Type("oneway_road",
-            "Oneway road");
-
-    /** The blocked street <code>Type</code> */
-    public static final Type BLOCKED_STREET = new Type("blocked_street",
-            "Blocked street");
-
-    /** The missing street <code>Type</code> */
-    public static final Type MISSING_STREET = new Type("missing_street",
-            "Missing street");
-
-    /** The wrong roundabout <code>Type</code> */
-    public static final Type WRONG_ROUNDABOUT = new Type("wrong_roundabout",
-            "Wrong roundabout");
-
-    /** The missing speedlimit <code>Type</code> */
-    public static final Type MISSING_SPEEDLIMIT = new Type(
-            "missing_speedlimit", "Missing speedlimit");
-
-    /** The other <code>Type</code> */
-    public static final Type OTHER = new Type("other", "Other");
-
-    /**
-     * Returns the <code>Type</code> for the given value.
-     *
-     * @param value The value
-     * @return A <code>Type</code> object
-     * @throws java.lang.IllegalStateException If the value is invalid
-     */
-    public static Type getType(java.lang.String value)
-            throws java.lang.IllegalStateException {
-        Type type = table.get(value);
-        if (type == null) {
-            type = Type.OTHER;
-        }
-        return type;
-    }
-
-    /**
-     * Returns the <code>Type</code> object for the given value. If there is no
-     * Type with the given value, the returned value is null.
-     *
-     * @param value The value of the type
-     * @return A <code>Type</code> object
-     */
-    public static Type getTypeFromValue(String value) {
-        Type type = null;
-        for (Type obj : table.values()) {
-            if (obj.getValue().equals(value)) {
-                type = obj;
-                break;
-            }
-        }
-        return type;
-    }
-
-    /**
-     * Returns all the types.
-     *
-     * @return An array of <code>Type</code> objects
-     */
-    public static Type[] getTypes() {
-        Collection<Type> collection = table.values();
-        return collection.toArray(new Type[0]);
-    }
-
-    /*
-     * (non-Javadoc)
-     *
-     * @see java.lang.Object#equals()
-     */
-    @Override
-    public boolean equals(java.lang.Object obj) {
-        return (obj == this);
-    }
-
-
-    /*
-     * (non-Javadoc)
-     *
-     * @see java.lang.Object#hashCode()
-     */
-    @Override
-    public int hashCode() {
-        return super.hashCode();
-    }
-
-    /**
-     * Returns the key
-     *
-     * @return the key
-     */
-    public String getKey() {
-        return key;
-    }
-
-    /**
-     * Returns the value
-     *
-     * @return the value
-     */
-    public String getValue() {
-        return value;
-    }
-
-}

Index: /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/model/TypesListModel.java
===================================================================
--- /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/model/TypesListModel.java	(revision 27873)
+++ /applications/editors/josm/plugins/mapdust/src/org/openstreetmap/josm/plugins/mapdust/gui/component/model/TypesListModel.java	(revision 27874)
@@ -31,9 +31,9 @@
 import javax.swing.AbstractListModel;
 import javax.swing.ComboBoxModel;
-import org.openstreetmap.josm.plugins.mapdust.service.value.Type;
+import org.openstreetmap.josm.plugins.mapdust.service.value.BugType;
 
 
 /**
  * The combo box model for the bug <code>Type</code>s.
  *
  * @author Bea
@@ -46,8 +46,8 @@
 
     /** The array of types */
-    private final Type[] types;
+    private final BugType[] types;
 
     /** The selected type */
-    private Type selection = null;
+    private BugType selection = null;
 
     /**
@@ -55,12 +55,12 @@
      */
     public TypesListModel() {
-        this.types = Type.getTypes();
+        this.types = BugType.getTypes();
     }
 
     /**
      * Returns the <code>Type</code> from the given position.
      *
      * @param index The position of the element
      * @return <code>Type</code> from the given position
      */
     @Override
@@ -80,5 +80,5 @@
 
     /**
      * Returns the selected <code>Type</code> object.
      *
      * @return selected item
@@ -90,5 +90,5 @@
 
     /**
      * Sets the selected <code>Type</code> object.
      *
      * @param anItem The selected item
@@ -96,5 +96,5 @@
     @Override
     public void setSelectedItem(Object anItem) {
-        selection = (Type) anItem;
+        selection = (BugType) anItem;
     }
 }
@@ -31,9 +31,9 @@
 
 /**
- * The combo box model for the bug <code>Type</code>s.
+ * The combo box model for the bug <code>BugType</code>s.
  *
  * @author Bea
@@ -55,12 +55,12 @@
 
     /**
-     * Returns the <code>Type</code> from the given position.
+     * Returns the <code>BugType</code> from the given position.
      *
      * @param index The position of the element
@@ -55,12 +55,12 @@
      *
      * @param index The position of the element
-     * @return <code>Type</code> from the given position
+     * @return <code>BugType</code> from the given position
      */
     @Override
@@ -80,5 +80,5 @@
 
     /**
-     * Returns the selected <code>Type</code> object.
+     * Returns the selected <code>BugType</code> object.
      *
      * @return selected item
@@ -90,5 +90,5 @@
 
     /**
-     * Sets the selected <code>Type</code> object.
+     * Sets the selected <code>BugType</code> object.
      *
      * @param anItem The selected item